Represents a Chronicle server address with host and port.
Summary
Types
@type t() :: %Chronicle.Connections.ConnectionString.ServerAddress{ host: String.t() | nil, port: non_neg_integer() | nil }
Represents a Chronicle server address with host and port.
@type t() :: %Chronicle.Connections.ConnectionString.ServerAddress{ host: String.t() | nil, port: non_neg_integer() | nil }